Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Game ¶
func (*Game) Register ¶
func (g *Game) Register(f aggregate.RegisterFunc)
Register is used to register the events and the aggregate to the internal register.
func (*Game) Transition ¶
func (g *Game) Transition(event eventsourcing.Event)
Transition is an method to transform events to game state. The state is then used to uphold the rules of the game. This method is needed for the Game to be an aggregate and be used by the functions in the aggregate package.
Click to show internal directories.
Click to hide internal directories.